==> wolfie-0.4.0.crate: wolfie-0.4.0/src/core/models.rs <==
use serde::{Deserialize, Serialize};
use std::convert::From;

/***************************/
/*-------------------------*/
/*--                     --*/
/*--    Config Models    --*/
/*--                     --*/
/*-------------------------*/
/***************************/

#[derive(Deserialize, Debug)]
pub struct Config {
    pub db_url: Option<String>,
    pub scan_period: Option<u64>,

    // N3NX Network APIs Config
    pub n3nx: ConfigN3NX,
    pub telegram: ConfigTelegram,
    pub twitter: ConfigTwitter,
    pub discord: ConfigDiscord,
    pub reddit: ConfigReddit,
}

#[derive(Deserialize, Debug)]
pub struct ConfigN3NX {
    pub fetch_url: String,
}

#[derive(Deserialize, Debug)]
pub struct ConfigTelegram {
    pub base_url: String,
    pub secret: String,
    pub chat_id: String,
}

#[derive(Deserialize, Debug)]
pub struct ConfigTwitter {
    pub base_url: String,
    pub api_key: String,
    pub api_secret: String,
    pub bearer_token: String,
    pub access_token: String,
    pub token_secret: String,
}

#[derive(Deserialize, Debug)]
pub struct ConfigDiscord {
    pub base_url: String,
    pub webhook_id: String,
    pub webhook_token: String,
}

#[derive(Deserialize, Debug)]
pub struct ConfigReddit {
    pub api_key: String,
    pub api_secret: String,
}

/***************************/
/*-------------------------*/
/*--                     --*/
/*--     N3N Models      --*/
/*--                     --*/
/*-------------------------*/
/***************************/

#[derive(Deserialize, Debug, Default)]
pub struct AllProjects {
    pub projects: Vec<Project>,
}

#[derive(Deserialize, Debug, Default)]
pub struct AllGithubRepos {
    pub total_count: u32,
    pub incomplete_results: bool,
    pub items: Vec<GithubRepo>,
}

#[derive(Deserialize, Debug)]
pub struct GithubRepo {
    pub name: String,
    pub description: String,
    pub html_url: String,
    pub url: String,
    pub default_branch: String,
    pub language: Option<String>,
    pub is_template: bool,
    pub stargazers_count: u32,
    pub watchers_count: u32,
    pub forks_count: u32,
    pub archived: bool,
    pub fork: bool,
    pub size: u32,
}

#[derive(Debug)]
pub struct ProjectMeta {
    pub tags: Vec<String>,
    pub featured: bool,
    pub emoji: String,
    pub template: bool,
}

#[derive(Deserialize, Debug, Default, PartialEq, Serialize)]
pub struct Project {
    pub name: String,
    pub desc: String,
    pub url: String,
    pub tags: Vec<String>,
    pub featured: bool,
    pub emoji: String,
    pub template: bool,
    pub branch: String,
}

#[derive(Debug)]
pub struct Changelog {
    pub project_name: String,
    pub hash: String,
    pub data: String,
}

#[derive(Debug, Serialize, Deserialize)]
pub struct StatefulChangelog {
    pub project_name: String,
    pub hash: String,
    pub prev_hash: String,
}

#[derive(Debug, Serialize, Deserialize)]
pub struct Version {
    pub project_name: String,
    pub hash: String,
    pub data: String,
    pub timestamp: i64,
    pub name: String,
    pub major: u8,
    pub minor: u8,
    pub patch: u8,
    pub codename: String,
    pub start_commit: String,
    pub end_commit: String,
}

/***************************/
/*-------------------------*/
/*--                     --*/
/*--    Social Models    --*/
/*--                     --*/
/*-------------------------*/
/***************************/

#[derive(Debug)]
pub struct Message {
    pub media_id: MediaId,
    pub message_id: String,
    pub message_hash: String,
    pub timestamp: i64,
    pub project_name: String,
    pub version_hash: String,
}

#[derive(Clone, Copy, Debug)]
pub enum MediaId {
    Telegram,
    Twitter,
    Reddit,
    Discord,
    LinkedIn,
    Slack,
}

impl From<MediaId> for &str {
    fn from(item: MediaId) -> Self {
        match item {
            MediaId::Discord => "discord",
            MediaId::LinkedIn => "linkedin",
            MediaId::Reddit => "reddit",
            MediaId::Slack => "slack",
            MediaId::Telegram => "telegram",
            MediaId::Twitter => "twitter",
        }
    }
}

==> wolfie-0.5.0.crate: wolfie-0.5.0/src/core/models.rs <==
use serde::{Deserialize, Serialize};
use std::convert::From;
use strum_macros::EnumIter;

/***************************/
/*-------------------------*/
/*--                     --*/
/*--    Config Models    --*/
/*--                     --*/
/*-------------------------*/
/***************************/

#[derive(Deserialize, Debug)]
pub struct Config {
    pub db_url: Option<String>,
    pub scan_period: Option<u64>,

    // N3NX Network APIs Config
    pub n3nx: ConfigN3NX,
    pub telegram: ConfigTelegram,
    pub twitter: ConfigTwitter,
    pub discord: ConfigDiscord,
    pub reddit: ConfigReddit,
}

#[derive(Deserialize, Debug)]
pub struct ConfigN3NX {
    pub fetch_url: String,
}

#[derive(Deserialize, Debug)]
pub struct ConfigTelegram {
    pub base_url: String,
    pub secret: String,
    pub chat_id: String,
}

#[derive(Deserialize, Debug)]
pub struct ConfigTwitter {
    pub base_url: String,
    pub api_key: String,
    pub api_secret: String,
    pub bearer_token: String,
    pub access_token: String,
    pub token_secret: String,
}

#[derive(Deserialize, Debug)]
pub struct ConfigDiscord {
    pub base_url: String,
    pub webhook_id: String,
    pub webhook_token: String,
}

#[derive(Deserialize, Debug)]
pub struct ConfigReddit {
    pub api_key: String,
    pub api_secret: String,
}

/***************************/
/*-------------------------*/
/*--                     --*/
/*--     N3N Models      --*/
/*--                     --*/
/*-------------------------*/
/***************************/

#[derive(Deserialize, Debug, Default)]
pub struct AllProjects {
    pub projects: Vec<Project>,
}

#[derive(Deserialize, Debug, Default)]
pub struct AllGithubRepos {
    pub total_count: u32,
    pub incomplete_results: bool,
    pub items: Vec<GithubRepo>,
}

#[derive(Deserialize, Debug)]
pub struct GithubRepo {
    pub name: String,
    pub description: String,
    pub html_url: String,
    pub url: String,
    pub default_branch: String,
    pub language: Option<String>,
    pub is_template: bool,
    pub stargazers_count: u32,
    pub watchers_count: u32,
    pub forks_count: u32,
    pub archived: bool,
    pub fork: bool,
    pub size: u32,
}

#[derive(Debug)]
pub struct ProjectMeta {
    pub tags: Vec<String>,
    pub featured: bool,
    pub emoji: String,
    pub template: bool,
}

#[derive(Deserialize, Debug, Default, PartialEq, Serialize)]
pub struct Project {
    pub name: String,
    pub desc: String,
    pub url: String,
    pub tags: Vec<String>,
    pub featured: bool,
    pub emoji: String,
    pub template: bool,
    pub branch: String,
}

#[derive(Debug)]
pub struct Changelog {
    pub project_name: String,
    pub hash: String,
    pub data: String,
}

#[derive(Debug, Serialize, Deserialize)]
pub struct StatefulChangelog {
    pub project_name: String,
    pub hash: String,
    pub prev_hash: String,
}

#[derive(Debug, Serialize, Deserialize)]
pub struct Version {
    pub project_name: String,
    pub hash: String,
    pub data: String,
    pub timestamp: i64,
    pub name: String,
    pub major: u8,
    pub minor: u8,
    pub patch: u8,
    pub codename: String,
    pub start_commit: String,
    pub end_commit: String,
}

/***************************/
/*-------------------------*/
/*--                     --*/
/*--    Social Models    --*/
/*--                     --*/
/*-------------------------*/
/***************************/

#[derive(Debug)]
pub struct Message {
    pub media_id: MediaId,
    pub message_id: String,
    pub message_hash: String,
    pub timestamp: i64,
    pub project_name: String,
    pub version_hash: String,
}

#[derive(Clone, Copy, Debug, EnumIter)]
pub enum MediaId {
    Telegram,
    Twitter,
    Reddit,
    Discord,
    LinkedIn,
    Slack,
}

impl From<MediaId> for &str {
    fn from(item: MediaId) -> Self {
        match item {
            MediaId::Discord => "discord",
            MediaId::LinkedIn => "linkedin",
            MediaId::Reddit => "reddit",
            MediaId::Slack => "slack",
            MediaId::Telegram => "telegram",
            MediaId::Twitter => "twitter",
        }
    }
}
